@@ -18,10 +18,12 @@ import click
 from veadk.cli.cli_deploy import deploy
 from veadk.cli.cli_eval import eval
 from veadk.cli.cli_init import init
+from veadk.cli.cli_create import create
 from veadk.cli.cli_kb import kb
 from veadk.cli.cli_pipeline import pipeline
 from veadk.cli.cli_prompt import prompt
 from veadk.cli.cli_web import web
+from veadk.cli.cli_uploadevalset import uploadevalset
 from veadk.version import VERSION
 
 
@@ -36,11 +38,13 @@ def veadk():
 
 veadk.add_command(deploy)
 veadk.add_command(init)
+veadk.add_command(create)
 veadk.add_command(prompt)
 veadk.add_command(web)
 veadk.add_command(pipeline)
 veadk.add_command(eval)
 veadk.add_command(kb)
+veadk.add_command(uploadevalset)
 
 if __name__ == "__main__":
     veadk()
