@@ -26,6 +26,7 @@ from fastmcp import FastMCP
 from starlette.routing import Route
 
 from google.adk.a2a.utils.agent_card_builder import AgentCardBuilder
+from a2a.types import AgentProvider
 
 from veadk.a2a.ve_a2a_server import init_app
 from veadk.runner import Runner
@@ -35,6 +36,8 @@ from veadk.tracing.telemetry.exporters.tls_exporter import TLSExporter
 from veadk.tracing.telemetry.opentelemetry_tracer import OpentelemetryTracer
 from veadk.types import AgentRunConfig
 from veadk.utils.logger import get_logger
+from opentelemetry.trace.propagation.tracecontext import TraceContextTextMapPropagator
+from opentelemetry import context
 
 logger = get_logger(__name__)
 
@@ -46,7 +49,9 @@ app_name = agent_run_config.app_name
 agent = agent_run_config.agent
 short_term_memory = agent_run_config.short_term_memory
 
-agent_card_builder = AgentCardBuilder(agent=agent)
+VEFAAS_REGION = os.getenv("APP_REGION", "cn-beijing")
+VEFAAS_FUNC_ID = os.getenv("_FAAS_FUNC_ID", "")
+agent_card_builder = AgentCardBuilder(agent=agent, provider=AgentProvider(organization="Volcengine Agent Development Kit (VeADK)", url=f"https://console.volcengine.com/vefaas/region:vefaas+{VEFAAS_REGION}/function/detail/{VEFAAS_FUNC_ID}"))
 
 
 def load_tracer() -> None:
@@ -114,6 +119,8 @@ async def agent_card() -> dict:
     agent_card = await agent_card_builder.build()
     return agent_card.model_dump()
 
+async def get_cozeloop_space_id() -> dict:
+    return {"space_id": os.getenv("OBSERVABILITY_OPENTELEMETRY_COZELOOP_SERVICE_NAME", default="")}
 
 load_tracer()
 
@@ -129,7 +136,7 @@ a2a_app = init_app(
 
 a2a_app.post("/run_agent", operation_id="run_agent", tags=["mcp"])(run_agent_func)
 a2a_app.get("/agent_card", operation_id="agent_card", tags=["mcp"])(agent_card)
-
+a2a_app.get("/get_cozeloop_space_id", operation_id="get_cozeloop_space_id", tags=["mcp"])(get_cozeloop_space_id)
 
 # === Build mcp server ===
 
@@ -156,6 +163,25 @@ app = FastAPI(
     redoc_url=None
 )
 
+@app.middleware("http")
+async def otel_context_middleware(request, call_next):
+    carrier = {
+        "traceparent": request.headers.get("Traceparent"),
+        "tracestate": request.headers.get("Tracestate"),
+    }
+    logger.debug(f"carrier: {carrier}")
+    if carrier["traceparent"] is None:
+        return await call_next(request)
+    else:
+        ctx = TraceContextTextMapPropagator().extract(carrier=carrier)
+        logger.debug(f"ctx: {ctx}")
+        token = context.attach(ctx)
+        try:
+            response = await call_next(request)
+        finally:
+            context.detach(token)
+    return response
+
 # Mount A2A routes to main app
 for route in a2a_app.routes:
     app.routes.append(route)
